WineBox - Wine Cellar Management
Author: Joe Drumgoole
Description: AI-powered wine cellar management. Scan wine labels with your phone, track your cellar inventory, discover tasting notes, and explore over 100,000 wines from around the world.

## Welcome to WineBox

Sign in to manage your wine cellar

Email
Password
Stay logged in on this machine
Forgot password? | Create account

## Create Account

Join WineBox to manage your wine cellar

Email
Password
At least 8 characters
Confirm Password
Already have an account? Sign in

## Reset Password

Enter your email to receive a password reset link

Email
← Back to sign in

## Set New Password

Enter your new password

New Password
At least 8 characters
Confirm New Password

## Verifying Email...

Please wait while we verify your email address.

Continue to sign in

## Dashboard

-
Bottles
-
Wines
-
Tracked
-
Met

### Wine Types

### Price Range

### Top Countries

### Top Grape Varieties

### Vintages

### Recent Activity

## Add Wine

Scan a label to record a wine you've encountered

### Label Images

Front Label (Required)
Tap to take photo or select image
Back Label (Optional)
Tap to take photo or select image

### Wine Details

Leave fields blank to use OCR-detected values

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Wine Type
More Details
Sub-Region
Appellation
Alcohol %
Classification
Price Tier
Producer Type
Drink Window Start
Drink Window End
Custom Fields
Notes

### Raw Label Text

+
Front Label OCR:

Back Label OCR:

## My Cellar

No Image
Malbec
Crios - 1973
Country Argentina
Region Mendoza
Grape: MalbecABV: 13.9%_demo: true
More...
No Image
Chardonnay
Far Niente - 2019
Country United States
Region Napa Valley
Grape: ChardonnayABV: 14.3%_demo: true
More...
No Image
La Montesa
Palacios Remondo - 2005
Country Spain
Region Rioja
Grape: GrenacheABV: 14%_demo: true
More...
No Image
Cuvée Réservée Rosé
Aime Roquesante - 2010
Country France
Region Côtes de Provence
Grape: CinsaultABV: 13%_demo: true
More...
No Image
Cabernet Sauvignon
Hess Select - 2014
Country United States
Region North Coast
Grape: Syrah/ShirazABV: 13.5%_demo: true
More...
No Image
Insignia
Joseph Phelps - 1958
Country United States
Region Napa Valley
Grape: Pinot NoirABV: 14.5%_demo: true
More...
No Image
Belleruche Côtes-du-Rhône Blanc
M. Chapoutier - 2020
Country France
Region Rhone Valley
Grape: Grenache BlancABV: 13%_demo: true
More...
No Image
Brunello di Montalcino
Biondi-Santi
Country Italy
Region Brunello di Montalcino
Grape: SangioveseABV: 10%_demo: true
More...
No Image
Cuvée Prestige Brut Champagne
Taittinger
Country France
Region Champagne
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
Reservado Sauvignon Blanc
Santa Helena - 1974
Country Chile
Region Central Valley (CL)
Grape: Sauvignon BlancABV: 12.5%_demo: true
More...
No Image
One Point Five Cabernet Sauvignon
Shafer - 1988
Country United States
Region Stags Leap District
Grape: Cabernet SauvignonABV: 15.1%_demo: true
More...
No Image
Mosaïque Brut Champagne
Jacquart
Country France
Region Champagne
Grape: ChardonnayABV: 12.5%_demo: true
More...
No Image
Rioja Reserva
Ondarre - 2013
Country Spain
Region Rioja
Grape: TempranilloABV: 13.5%_demo: true
More...
No Image
Benjamin Malbec
Nieto Senetiner - 1998
Country Argentina
Region Mendoza
Grape: MalbecABV: 12.5%_demo: true
More...
No Image
Vinho Verde
Casal Garcia
Country Portugal
Region Vinho Verde
Grape: LoureiroABV: 9.5%_demo: true
More...
No Image
Oro Tempranillo Valdepeñas
Pata Negra - 2015
Country Spain
Region Valdepeñas
Grape: TempranilloABV: 13%_demo: true
More...
No Image
Colheita Seleccionada Rouge
Rapariga da Quinta - 2016
Country Portugal
Region Alentejano
Grape: Cabernet SauvignonABV: 14%_demo: true
More...
No Image
Amarone della Valpolicella Classico
Zenato - 1970
Country Italy
Region Veneto
Grape: CorvinaABV: 16.5%_demo: true
More...
No Image
Torrontés
Colomé - 1990
Country Argentina
Region Cafayate Valley
Grape: TorrontésABV: 13.5%_demo: true
More...
No Image
Old Vines Garnacha
Evodia - 2007
Country Spain
Region Calatayud
Grape: GarnachaABV: 15%_demo: true
More...
No Image
Tinto (Touriga Nacional-Syrah-Aragonez)
Ciconia - 2000
Country Portugal
Region Alentejano
Grape: Syrah/ShirazABV: 13.3%_demo: true
More...
No Image
Château Margaux (Premier Grand Cru Classé)
Château Margaux - 2012
Country France
Region Margaux
Grape: Cabernet SauvignonABV: 13%_demo: true
More...
No Image
Cabernet Sauvignon Rosé
Mulderbosch - 2000
Country South Africa
Region Stellenbosch
Grape: Cabernet SauvignonABV: 13.6%_demo: true
More...
No Image
Talò Primitivo di Manduria
San Marzano - 2007
Country Italy
Region Primitivo di Manduria
Grape: PrimitivoABV: 14%_demo: true
More...
No Image
Gran Tarapacá Reserva Carmenère
Tarapacá - 1952
Country Chile
Region Maipo Valley
Grape: CarmenèreABV: 13.8%_demo: true
More...
No Image
Phantom
Bogle - 1987
Country United States
Region California
Grape: ZinfandelABV: 14.5%_demo: true
More...
No Image
Sauvignon Blanc
Mount Riley - 2008
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13%_demo: true
More...
No Image
Brut La Francaise Champagne
Taittinger
Country France
Region Champagne
Grape: Pinot MeunierABV: 12.3%_demo: true
More...
No Image
Ca'Marcanda Promis Toscana
Gaja - 2016
Country Italy
Region Toscana
Grape: Syrah/ShirazABV: 14%_demo: true
More...
No Image
Contacto Alvarinho
Anselmo Mendes - 2001
Country Portugal
Region Vinho Verde
Grape: AlvarinhoABV: 13%_demo: true
More...
No Image
La Grande Année Brut Champagne
Bollinger - 2016
Country France
Region Champagne
Grape: Pinot NoirABV: 12%_demo: true
More...
No Image
Château de Selle Rosé (Coeur de Grain)
Domaines Ott - 1987
Country France
Region Côtes de Provence
Grape: CinsaultABV: 13.5%_demo: true
More...
No Image
Cabernet Sauvignon
Tom Gore - 2015
Country United States
Region California
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Chardonnay
Grgich Hills - 1983
Country United States
Region Napa Valley
Grape: ChardonnayABV: 14.1%_demo: true
More...
No Image
Rosé Brut Champagne (Vintage)
Louis Roederer - 2021
Country France
Region Champagne
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
Jumilla Silver Label
Juan Gil - 2006
Country Spain
Region Jumilla
Grape: MonastrellABV: 15%_demo: true
More...
No Image
Vinho Verde
Aveleda - 2018
Country Portugal
Region Vinho Verde
Grape: LoureiroABV: 10%_demo: true
More...
No Image
Adobe Chardonnay (Reserva)
Emiliana - 1998
Country Chile
Region Rapel Valley
Grape: ChardonnayABV: 13.6%_demo: true
More...
No Image
Rosé
Villa Francioni - 1990
Country Brazil
Region Santa Catarina
Grape: Syrah/ShirazABV: 13.2%_demo: true
More...
No Image
Terroir de Familia Reserva Carmenère
Casa Silva - 1993
Country Chile
Region Colchagua Valley
Grape: CarmenèreABV: 14%_demo: true
More...
No Image
Vin de Constance (Natural Sweet)
Klein Constantia - 1971
Country South Africa
Region Constantia
Grape: Muscat of FrontignanABV: 14%_demo: true
More...
No Image
Valtier Utiel-Requena Reserva
Faustino Rivero Ulecia - 2009
Country Spain
Region Rioja
Grape: TempranilloABV: 13%_demo: true
More...
No Image
Chardonnay
Woodbridge by Robert Mondavi - 2021
Country United States
Region California
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
Rioja Gran Reserva
Beronia - 1986
Country Spain
Region Rioja
Grape: TempranilloABV: 14%_demo: true
More...
No Image
Pinot Noir
Le Grand Noir - 2016
Country France
Region Languedoc-Roussillon
Grape: Pinot NoirABV: 12.5%_demo: true
More...
No Image
Unico
Vega Sicilia - 1951
Country Spain
Region Ribera del Duero
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Reservado Cabernet Sauvignon
Santa Helena - 2008
Country Chile
Region Central Valley (CL)
Grape: Cabernet SauvignonABV: 14%_demo: true
More...
No Image
De Nit Rosado
Raventós i Blanc - 2010
Country Spain
Region Catalunya
Grape: MacabeoABV: 11.9%_demo: true
More...
No Image
Te Koko Sauvignon Blanc
Cloudy Bay - 2020
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13%_demo: true
More...
No Image
Unoaked Chardonnay
La Linda - 2011
Country Argentina
Region Mendoza
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
Saint-Julien
Château Gloria - 1960
Country France
Region Saint-Julien
Grape: Cabernet SauvignonABV: 12.8%_demo: true
More...
No Image
Gran Reserva Cabernet Sauvignon
Toro de Piedra - 2010
Country Chile
Region Curico Valley
Grape: Cabernet SauvignonABV: 14.5%_demo: true
More...
No Image
St. Henri Shiraz
Penfolds - 1979
Country Australia
Region South Australia
Grape: Syrah/ShirazABV: 14.5%_demo: true
More...
No Image
Cellar Selection Marlborough Sauvignon Blanc
Sileni Estates - 2001
Country New Zealand
Region Hawke's Bay
Grape: Sauvignon BlancABV: 12.5%_demo: true
More...
No Image
Cabernet Sauvignon
Oberon - 2009
Country United States
Region Napa County
Grape: Cabernet SauvignonABV: 13.7%_demo: true
More...
No Image
Brut Champagne
Krug - 1965
Country France
Region Champagne
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
Pinot Noir (Reserva)
Leyda - 2003
Country Chile
Region Leyda Valley
Grape: Pinot NoirABV: 14.5%_demo: true
More...
No Image
Pinot Bianco Riserva Vorberg
Terlan (Terlano) - 1987
Country Italy
Region Südtirol-Alto Adige
Grape: WeissburgunderABV: 14%_demo: true
More...
No Image
Dairyman Vineyard Pinot Noir
Belle Glos - 2013
Country United States
Region Russian River Valley
Grape: Pinot NoirABV: 14.6%_demo: true
More...
No Image
Reservado White Zinfandel
Concha y Toro - 2021
Country United States
Region California
Grape: Zinfandel WhiteABV: 10.5%_demo: true
More...
No Image
Sauvignon Blanc
Brancott Estate - 1962
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13.1%_demo: true
More...
No Image
Falanghina
Feudi di San Gregorio - 2003
Country Italy
Region Campania
Grape: FalanghinaABV: 13.5%_demo: true
More...
No Image
Barolo
Pio Cesare - 1965
Country Italy
Region Piemonte
Grape: NebbioloABV: 14.5%_demo: true
More...
No Image
Villa Antinori Chianti Classico Riserva
Antinori - 1977
Country Italy
Region Chianti Classico
Grape: SangioveseABV: 13.5%_demo: true
More...
No Image
Crianza
Hacienda López de Haro - 2014
Country Spain
Region Rioja
Grape: TempranilloABV: 13.5%_demo: true
More...
No Image
Regaleali Bianco Sicilia
Tasca d'Almerita - 1988
Country Italy
Region Terre Siciliane
Grape: AnsonicaABV: 12%_demo: true
More...
No Image
Vinho Verde Branco
Via Latina - 2013
Country Portugal
Region Vinho Verde
Grape: Arinto de BucelasABV: 11%_demo: true
More...
No Image
Chardonnay
Bogle - 2012
Country United States
Region California
Grape: ChardonnayABV: 13.5%_demo: true
More...
No Image
Barolo
Batasiolo - 1981
Country Italy
Region Barolo
Grape: NebbioloABV: 14%_demo: true
More...
No Image
Mas La Plana Cabernet Sauvignon
Familia Torres - 2004
Country Spain
Region Penedès
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Butterfly Ridge Riesling-Gewürztraminer
Angove - 2009
Country Australia
Region South Australia
Grape: GewürztraminerABV: 12.5%_demo: true
More...
No Image
Famiglia Bianchi Malbec Reserva
Bodegas Bianchi - 1996
Country Argentina
Region Mendoza
Grape: MalbecABV: 14%_demo: true
More...
No Image
Nussbaumer Gewürztraminer
Tramin - 2009
Country Italy
Region Trentino-Alto Adige
Grape: GewürztraminerABV: 15.1%_demo: true
More...
No Image
Blue Top Brut Champagne
Heidsieck & Co. Monopole
Country France
Region Champagne
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
V Douce France Vouvray
Famille Bougrier - 1990
Country France
Region Loire Valley
Grape: Chenin BlancABV: 12%_demo: true
More...
No Image
Adobe Rosé (Reserva)
Emiliana - 2010
Country Chile
Region Rapel Valley
Grape: Syrah/ShirazABV: 12.1%_demo: true
More...
No Image
Cabernet Sauvignon
Marques de Casa Concha - 2008
Country Chile
Region Central Valley (CL)
Grape: Cabernet SauvignonABV: 14%_demo: true
More...
No Image
Trumpeter Malbec
Rutini - 2003
Country Argentina
Region Mendoza
Grape: MalbecABV: 13.7%_demo: true
More...
No Image
Saint-Émilion Grand Cru (Grand Cru Classé)
Château Fombrauge - 1991
Country France
Region Saint-Émilion Grand Cru
Grape: MerlotABV: 12.5%_demo: true
More...
No Image
Cuvée Brut Champagne
Piper-Heidsieck
Country France
Region Champagne
Grape: Pinot MeunierABV: 12%_demo: true
More...
No Image
Granbazán Albariño Etiqueta Ámbar
Agro de Bazán - 2004
Country Spain
Region Galicia
Grape: AlbariñoABV: 12.5%_demo: true
More...
No Image
Primo Primitivo
Torrevento - 2015
Country Italy
Region Puglia
Grape: PrimitivoABV: 13.5%_demo: true
More...
No Image
Douro Duas Quintas Branco
Ramos Pinto - 1999
Country Portugal
Region Douro
Grape: ViosinhoABV: 13%_demo: true
More...
No Image
Torrontes
Alamos - 1998
Country Argentina
Region Salta
Grape: TorrontésABV: 13.5%_demo: true
More...
No Image
Vinho Tinto
Casal Garcia - 2001
Country Portugal
Region Porto
Grape: VinhãoABV: 11%_demo: true
More...
No Image
Dr. L Riesling
Dr. Loosen - 2004
Country Germany
Region Mosel
Grape: RieslingABV: 8.5%_demo: true
More...
No Image
Reserva
Colossal - 2011
Country Portugal
Region Lisboa
Grape: Syrah/ShirazABV: 14%_demo: true
More...
No Image
Sauvignon Blanc
Greywacke - 2011
Country New Zealand
Region Marlborough
Grape: Sauvignon BlancABV: 13.4%_demo: true
More...
No Image
Barolo Serralunga d'Alba
Fontanafredda - 1972
Country Italy
Region Barolo
Grape: NebbioloABV: 13.5%_demo: true
More...
No Image
Reserva Rioja (Finca Ygay)
Marqués de Murrieta - 2008
Country Spain
Region Rioja
Grape: TempranilloABV: 14%_demo: true
More...
No Image
Le Mesnil Blanc de Blancs (Cuvée S) Brut Champagne
Salon - 1987
Country France
Region Champagne
Grape: ChardonnayABV: 12%_demo: true
More...
No Image
Pauillac (Grand Cru Classé)
Château Batailley - 1996
Country France
Region Pauillac
Grape: Petit VerdotABV: 12.5%_demo: true
More...
No Image
Blanco
El Coto - 2007
Country Spain
Region Rioja
Grape: VerdejoABV: 12%_demo: true
More...
No Image
Pequeñas Producciones Malbec
Escorihuela Gascón - 2021
Country Argentina
Region Mendoza
Grape: MalbecABV: 14%_demo: true
More...
No Image
Nicasia Vineyards Red Blend Cabernet Franc
Catena Zapata - 1973
Country Argentina
Region Mendoza
Grape: Petit VerdotABV: 13.8%_demo: true
More...
No Image
Sonoma Coast Pinot Noir
La Crema - 2017
Country United States
Region Sonoma Coast
Grape: Pinot NoirABV: 14%_demo: true
More...
No Image
Dark (Red Blend)
Apothic - 1999
Country United States
Region California
Grape: ZinfandelABV: 13.9%_demo: true
More...
No Image
Tokaji Kësõi Szüret Late Harvest
Disznókó - 2011
Country Hungary
Region Tokaj
Grape: FurmintABV: 12%_demo: true
More...
No Image
Cabernet Sauvignon
Ravage - 2019
Country United States
Region California
Grape: Cabernet SauvignonABV: 13.5%_demo: true
More...
No Image
Clio
Bodegas El Nido - 1982
Country Spain
Region Jumilla
Grape: MourvedreABV: 15.5%_demo: true
More...

## Wines I've Met

Wines you've encountered in shops, restaurants, and tastings

## Add Wine to Your Cellar

Choose how you'd like to add a wine

### Scan a Label

Take a photo to auto-detect wine details

### Enter Details Manually

Type in the wine details and quantity

### From a Wine I've Met

Add a wine you previously recorded

### Import from File

Upload a CSV or Excel spreadsheet

### Scan Label

Front Label (Required)
Tap to take photo or select image
Back Label (Optional)
Tap to take photo or select image
Scanning label...

### Wine Details

Detected from label — edit as needed

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Wine Type
Quantity (Bottles)

### Enter Wine Details

Wine Name
Winery
Vintage
Grape Variety
Region
Country
Wine Type
Quantity (Bottles)

### Select a Wine You've Met

####

How many bottles?

### Upload Spreadsheet

Drag and drop your file here, or

Browse Files

Supported formats: CSV, Excel (.xlsx). Max 10,000 rows.

We'll help you match your columns in the next step. Nothing is imported until you confirm.

Advanced import options...
Always show column mapping step Use AI to automatically match columns (takes a few extra seconds)

### Match Your Columns

Tell us what each column in your spreadsheet contains. We've made our best guess — just check and adjust anything that looks wrong.

### Your data (first 5 rows)

No quantity column matched — each wine will be added as 1 bottle.

### Adding wines to your cellar...

0 / 0 rows 0%
0 wines created 0 rows skipped
Skip automatic detail lookup (faster, but missing details like region or grape won't be filled in)

### Import Complete

### We already have this data

### Add More Details

These columns from your file weren't imported. Map them to wine fields to add the information to your wines.

### Just Added

### Your New Wines

### Your Cellar at a Glance

×

## Transaction History

### Activity Timeline

### Removal Reasons

### Activity Summary

## Search Wines

Search
Advanced Filters
Vintage
Grape Variety
Winery
Region
Country
Wine Type
Price Tier
In Stock Only

## Wine Reference

Search over 100,000 wines from around the world

Search
Wine Type
Country
Results
Price Range (USD)
to
Page 1 of 1
×

## Settings

### Change Password

Current Password
New Password
Confirm New Password

### Danger Zone

Permanently delete your entire wine collection, including all wines, transactions, label images, and import history. This action cannot be undone.

×

### Remove Wine

What happened to this wine?

Quantity
Tasting notes (optional)
Sale price ($)
Who did you give it to?
What happened? (optional)
×

### Confirm Wine Details

Review and edit the details before saving

Wine Name
Winery
Vintage
Grape Variety
Region
Sub-Region
Appellation
Country
Alcohol %
Wine Type
Classification
Price Tier
Producer Type
Custom Fields
Notes
Show Raw Label Text +
Front Label:

Back Label:

How many bottles?
×

### Delete Entire Collection

This will permanently delete all your wines, transactions, label images, and import history. This action cannot be undone.

Type DELETE to confirm:
×

### Delete Wine

Are you sure you want to delete this wine and all its history? This action cannot be undone.

×

### Skipped Rows